import { create } from 'zustand'

type State = {
    isDragging: boolean,
    files: File[],
    openModalDrop: boolean,
    setFiles: (files: File[]) => void,
    setModalDrop: (openModalDrop: boolean) => void,
    setIsDragging: (isDragging: boolean) => void,
    handleDrop: (e: any) => void,
    handleDragEnter: (e: any, selectedSesion?: any, permission?: boolean) => void
}

const useDragAndDropStore = create<State>((set, get) => ({
    isDragging: false,
    openModalDrop: false,
    files: [],
    setFiles: (files: File[]) => set({ files: files }),
    setModalDrop: (openModalDrop: boolean) => set({ openModalDrop: openModalDrop }),
    setIsDragging: (isDragging: boolean) => set({ isDragging: isDragging }),
    handleDrop: (dataFiles: File[]) => {
        if (dataFiles.length === 0) {
            return
        }

        set({ files: dataFiles })
        set({ openModalDrop: true })
        set({ isDragging: false })
    },
    handleDragEnter: (e: any, selectedSesion?: any, permission?: boolean) => {
        e.preventDefault();

        if (selectedSesion.sesion == '') {
            return
        }
        if (permission === false) {
            return
        }
        if (get().openModalDrop === true) {
            return
        }

        const type = e.type;

        if (type === 'dragover') {
            set({ isDragging: true })
        } else if (type === 'dragenter') {
            set({ isDragging: true })
        } else if (type === 'dragleave') {
            setTimeout(() => {
                set({ isDragging: false })
            }, 1500);
        }/* else if (type === 'drop') {
            set({ isDragging: false })
        }*/
    },
}))

export default useDragAndDropStore